@@ -1,5 +1,5 @@
 /*
-    Copyright (C) 2004  Dale Mellor
+    Copyright (C) 2004, 2010  Dale Mellor
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -19,28 +19,13 @@
 #define GUILE_HOOKS_H
 
 
-#include <libguile.h>
 #include <gtk/gtk.h>
 
-/* Data type to implement a singly-linked list of GtkItemFactoryEntry
-   objects. */
-
-typedef struct _Menu_Item_List
-{
-    GtkItemFactoryEntry entry;
-    char *callback_data;
-    struct _Menu_Item_List *next;
-} Menu_Item_List;
-
-
-
-/* The method which seeks out all scripts and executes them. The scripts can
-   callback to the C world to register themselves. On completion,  the function
-   returns a list of registered items. The function must be called exactly
-   once. */
-
-Menu_Item_List *startup_guile_scripts (void);
 
+/* The method which seeks out all scripts, and makes them known to 
+   the UI manager. The scripts can callback to the C world to register
+   themselves. The function must be called exactly once. */
 
+void startup_guile_scripts (GtkUIManager * uim);
 
 #endif /* defined GUILE_HOOKS_H. */
