@@ -72,7 +72,7 @@ new_view (GbkGame * game, const gchar * description, const gfloat * aspect)
 
   gtk_window_set_icon_name (GTK_WINDOW (window), "gnubik");
 
-  title = g_strdup_printf ("%s %s", PACKAGE, description);
+  title = g_strdup_printf ("%s %s", _(PACKAGE_NAME), description);
 
   gtk_window_set_title (GTK_WINDOW (window), title);
 
@@ -549,7 +549,7 @@ error_dialog (GtkWindow * parent, const gchar * format, ...)
   dialog = gtk_message_dialog_new (parent,
 				   GTK_DIALOG_MODAL,
 				   GTK_MESSAGE_ERROR,
-				   GTK_BUTTONS_CLOSE, message);
+				   GTK_BUTTONS_CLOSE, "%s", message);
   g_free (message);
 
   gtk_window_set_title (GTK_WINDOW (dialog), _("Gnubik error"));
